==> haskell-vector-binary-instances-0.2.4-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-vector-binary-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vector-binary-instances
version: 0.2.4
id: vector-binary-instances-0.2.4-DozAADK9jE3EJNfe3MCYFT
key: vector-binary-instances-0.2.4-DozAADK9jE3EJNfe3MCYFT
license: BSD-3-Clause
maintainer: dons00@gmail.com, bos@serpentine.com, Ben Gamari <ben@smart-cactus.org>
author: Don Stewart
stability: Experimental
homepage: https://github.com/bos/vector-binary-instances
synopsis: Instances of Data.Binary and Data.Serialize for vector
description:
    Instances for Binary for the types defined in the vector package,
    making it easy to serialize vectors to and from disk. We use the
    generic interface to vectors, so all vector types are supported.
    Specific instances are provided for unboxed, boxed and storable
    vectors.
    .
    To serialize a vector:
    .
    > *Data.Vector.Binary> let v = Data.Vector.fromList [1..10]
    > *Data.Vector.Binary> v
    > fromList [1,2,3,4,5,6,7,8,9,10] :: Data.Vector.Vector
    > *Data.Vector.Binary> encode v
    > Chunk "\NUL\NUL\NUL\NUL\NUL...\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\n" Empty
    .
    Which you can in turn compress before writing to disk:
    .
    > compress . encode $ v
    > Chunk "\US\139\b\NUL\NUL\N...\229\240,\254:\NUL\NUL\NUL" Empty
category: Data
abi: 4af3da0c5bb322189526ac895cb4daad
exposed: True
exposed-modules:
    Data.Vector.Binary
import-dirs: /usr/lib/ghc-8.4.3/site-local/vector-binary-instances-0.2.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/vector-binary-instances-0.2.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/vector-binary-instances-0.2.4
hs-libraries: HSvector-binary-instances-0.2.4-DozAADK9jE3EJNfe3MCYFT
depends:
    base-4.11.1.0 vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq binary-0.8.5.1
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
             binary-0.8.5.1=758db3c95031800de821949083b71c7f
haddock-interfaces: /usr/share/doc/haskell-vector-binary-instances/html/vector-binary-instances.haddock
haddock-html: /usr/share/doc/haskell-vector-binary-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-binary-instances-0.2.5-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-vector-binary-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vector-binary-instances
version: 0.2.5
id: vector-binary-instances-0.2.5-4WROCM1RYq53hip5v4A4DR
key: vector-binary-instances-0.2.5-4WROCM1RYq53hip5v4A4DR
license: BSD-3-Clause
maintainer: dons00@gmail.com, bos@serpentine.com, Ben Gamari <ben@smart-cactus.org>
author: Don Stewart
stability: Experimental
homepage: https://github.com/bos/vector-binary-instances
synopsis: Instances of Data.Binary for vector
description:
    Instances for Binary for the types defined in the vector package,
    making it easy to serialize vectors to and from disk. We use the
    generic interface to vectors, so all vector types are supported.
    Specific instances are provided for unboxed, boxed and storable
    vectors.
    .
    To serialize a vector:
    .
    > *Data.Vector.Binary> let v = Data.Vector.fromList [1..10]
    > *Data.Vector.Binary> v
    > fromList [1,2,3,4,5,6,7,8,9,10] :: Data.Vector.Vector
    > *Data.Vector.Binary> encode v
    > Chunk "\NUL\NUL\NUL\NUL\NUL...\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\n" Empty
    .
    Which you can in turn compress before writing to disk:
    .
    > compress . encode $ v
    > Chunk "\US\139\b\NUL\NUL\N...\229\240,\254:\NUL\NUL\NUL" Empty
    .
    Try the cereal-vector package if you are looking for Data.Serialize
    instances.
category: Data
abi: cc080c4f6651d9f33ec58002526085de
exposed: True
exposed-modules:
    Data.Vector.Binary
import-dirs: /usr/lib/ghc-8.4.3/site-local/vector-binary-instances-0.2.5
library-dirs: /usr/lib/ghc-8.4.3/site-local/vector-binary-instances-0.2.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/vector-binary-instances-0.2.5
hs-libraries: HSvector-binary-instances-0.2.5-4WROCM1RYq53hip5v4A4DR
depends:
    base-4.11.1.0 vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq binary-0.8.5.1
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
             binary-0.8.5.1=758db3c95031800de821949083b71c7f
haddock-interfaces: /usr/share/doc/haskell-vector-binary-instances/html/vector-binary-instances.haddock
haddock-html: /usr/share/doc/haskell-vector-binary-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
